
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alexandr
Alexei
Caleb
Christian
Christopher
Ciornii
Cushing
David
Dist
FileFinder
Golden
Graham
Grahan
Ian
Loyd
Madsen
Ollis
OurPkgVersion
Plugin
Sealy
Stephan
SubmittingPatches
Walde
Zilla
Znamensky
alexchorny
dagolden
dzil
executables
git
ini
lib
perl
perltidy
plicease
russoz
stephanloyd9
walde
xenoterracide
